==> release.12.0.73.1.tgz: prontus/cpan/youtube_post/config.php <==
<?php
// prevenir invocacion directa del script
defined('PRONTUS') OR exit('');

/**
 * Este archivo de configuración fue extraído de la solución para posting a youtube, http://192.168.8.27/prontus/soluciones/youtube/
 *
 * Dado que se integró a Prontus, se eliminan varias configuraciones, o se leen directamente del sistema, como el document_root, el nombre de prontus, etc. El archivo ya no debe modificarse a mano, sino que lee la configuración desde el archivo cpan/[prontus]-redes.cfg.
 *
 * Para documentación, estos son los datos necesarios para hacer posting a youtube:

 * $YOUTUBE_APPNAME =  'Youtube';
 * $YOUTUBE_REDIRECT_URI =  'urn:ietf:wg:oauth:2.0:oob';
 * $YOUTUBE_URL_OAUTH_TOKEN =  'https://accounts.google.com/o/oauth2/token';
 * $YOUTUBE_CLIENT_ID =  '552186299426-48keceff4hm6un4obj89sqhseidukglk.apps.googleusercontent.com';
 * $YOUTUBE_CLIENT_SECRET =  'X1uthigQEXfFgQRlV9stfnZe';
 * $YOUTUBE_REFRESH_TOKEN =  '1/l5hk7XJm3gupT0e2rV828K6MugDCbuN3WDbRmnp3Kic';
 */

$CONFIG_YOUTUBE = array('success' => 1, 'msg' => ''); // para éxito
$ERROR_RESPONSE = array('success' => 0, 'msg' => ''); // para errores

# este script puede ser llamado desde CLI o web, hay que considerar ambos casos.
$CONFIG_YOUTUBE['DOCUMENT_ROOT'] = __DIR__ .'/../../..';
if (!empty($_SERVER['DOCUMENT_ROOT'])) {
    $CONFIG_YOUTUBE['DOCUMENT_ROOT'] = $_SERVER['DOCUMENT_ROOT'];
}

$CONFIG_YOUTUBE['YOUTUBE_REDIRECT_URI'] = 'urn:ietf:wg:oauth:2.0:oob';
$CONFIG_YOUTUBE['YOUTUBE_URL_OAUTH_TOKEN'] = 'https://accounts.google.com/o/oauth2/token';
$CONFIG_YOUTUBE['SCOPES'] = array('https://www.googleapis.com/auth/youtube.upload', 'https://www.googleapis.com/auth/youtube', 'https://www.googleapis.com/auth/youtubepartner');

// no hay argumentos => es via web
if (sizeof($argv) < 1) {
    $sesion = false;
    foreach ($_COOKIE as $key => $value) {
        if (preg_match('/SESSION_(.+)/', $key, $matches) ) {
            # Revisamos que exista la sesion en prontus
            # se prueba con todas las cookies ya que puede existir mas de 1 prontus en un servidor
            if (file_exists($CONFIG_YOUTUBE['DOCUMENT_ROOT'].'/'.$matches[1].'/cpan/data/users/sessions/'.$value)) {
                $sesion = true;
            }
        }
    }
    if (!$sesion) {
        exit;
    }
}

# este script puede ser llamado desde CLI o web, hay que considerar ambos casos.
if (empty($_GET['_prontus_id']) && empty($input['prontus_id'])) {
    $ERROR_RESPONSE['msg'] = "Debe especificarse el parámetro '_prontus_id'";
    print json_encode($ERROR_RESPONSE);
    exit;
}

if (empty($input['prontus_id'])) {
    $CONFIG_YOUTUBE['PRONTUS_ID'] = $_GET['_prontus_id'];
} else {
    $CONFIG_YOUTUBE['PRONTUS_ID'] = $input['prontus_id'];
}

# Revisamos que exista la config de Prontus:
if (! file_exists($CONFIG_YOUTUBE['DOCUMENT_ROOT'].'/'.$CONFIG_YOUTUBE['PRONTUS_ID'].'/cpan/'.$CONFIG_YOUTUBE['PRONTUS_ID'].'-bd.cfg')) {
    $ERROR_RESPONSE['msg'] = "No pudo encontrarse la configuración de Prontus.";
    print json_encode($ERROR_RESPONSE);
    exit;
}

# Revisamos que exista la config de redes sociales:
if (! file_exists($CONFIG_YOUTUBE['DOCUMENT_ROOT'].'/'.$CONFIG_YOUTUBE['PRONTUS_ID'].'/cpan/'.$CONFIG_YOUTUBE['PRONTUS_ID'].'-redes.cfg')) {
    $ERROR_RESPONSE['msg'] = "No pudo encontrarse el archivo de configuración de Posting a Redes Sociales.";
    print json_encode($ERROR_RESPONSE);
    exit;
}

# leemos el archivo de config.
$opciones_redes = parse_ini_file($CONFIG_YOUTUBE['DOCUMENT_ROOT'].'/'.$CONFIG_YOUTUBE['PRONTUS_ID'].'/cpan/'.$CONFIG_YOUTUBE['PRONTUS_ID'].'-redes.cfg');
if ($opciones_redes === FALSE) {
    $ERROR_RESPONSE['msg'] = "No pudo leerse el archivo de configuración de Posting a Redes Sociales.";
    print json_encode($ERROR_RESPONSE);
    exit;
}

foreach ($opciones_redes as $key=>$value) {
    if (strpos($key, 'YOUTUBE_') === 0) {
        $CONFIG_YOUTUBE[$key] = $value;
    }
}

// Estado de privacidad del video. Pasar a Public para productivo.
$CONFIG_YOUTUBE['PRIVACY_STATUS'] = 'unlisted'; //Options are "public", "private" and "unlisted".

# limpiamos variable que ya no sirve.
unset($opciones_redes);

==> release.12.3.1.2.tgz: prontus/cpan/youtube_post/config.php <==
<?php
// prevenir invocacion directa del script
defined('PRONTUS') OR exit('');

/**
 * Este archivo de configuración fue extraído de la solución para posting a youtube, http://192.168.8.27/prontus/soluciones/youtube/
 *
 * Dado que se integró a Prontus, se eliminan varias configuraciones, o se leen directamente del sistema, como el document_root, el nombre de prontus, etc. El archivo ya no debe modificarse a mano, sino que lee la configuración desde el archivo cpan/[prontus].cfg.
 *
 * Para documentación, estos son los datos necesarios para hacer posting a youtube:

 * $YOUTUBE_APPNAME =  'Youtube';
 * $YOUTUBE_REDIRECT_URI =  'urn:ietf:wg:oauth:2.0:oob';
 * $YOUTUBE_URL_OAUTH_TOKEN =  'https://accounts.google.com/o/oauth2/token';
 * $YOUTUBE_CLIENT_ID =  '552186299426-48keceff4hm6un4obj89sqhseidukglk.apps.googleusercontent.com';
 * $YOUTUBE_CLIENT_SECRET =  'X1uthigQEXfFgQRlV9stfnZe';
 * $YOUTUBE_REFRESH_TOKEN =  '1/l5hk7XJm3gupT0e2rV828K6MugDCbuN3WDbRmnp3Kic';
 */

$CONFIG_YOUTUBE = array('success' => 1, 'msg' => ''); // para éxito
$ERROR_RESPONSE = array('success' => 0, 'msg' => ''); // para errores

# este script puede ser llamado desde CLI o web, hay que considerar ambos casos.
$CONFIG_YOUTUBE['DOCUMENT_ROOT'] = __DIR__ .'/../../..';
if (!empty($_SERVER['DOCUMENT_ROOT'])) {
    $CONFIG_YOUTUBE['DOCUMENT_ROOT'] = $_SERVER['DOCUMENT_ROOT'];
}

$CONFIG_YOUTUBE['YOUTUBE_REDIRECT_URI'] = 'urn:ietf:wg:oauth:2.0:oob';
$CONFIG_YOUTUBE['YOUTUBE_URL_OAUTH_TOKEN'] = 'https://accounts.google.com/o/oauth2/token';
$CONFIG_YOUTUBE['SCOPES'] = array('https://www.googleapis.com/auth/youtube.upload', 'https://www.googleapis.com/auth/youtube', 'https://www.googleapis.com/auth/youtubepartner');

// no hay argumentos => es via web
if (sizeof($argv) < 1) {
    $sesion = false;
    foreach ($_COOKIE as $key => $value) {
        if (preg_match('/SESSION_(.+)/', $key, $matches) ) {
            # Revisamos que exista la sesion en prontus
            # se prueba con todas las cookies ya que puede existir mas de 1 prontus en un servidor
            if (file_exists($CONFIG_YOUTUBE['DOCUMENT_ROOT'].'/'.$matches[1].'/cpan/data/users/sessions/'.$value)) {
                $sesion = true;
            }
        }
    }
    if (!$sesion) {
        exit;
    }
}

# este script puede ser llamado desde CLI o web, hay que considerar ambos casos.
if (empty($_GET['_prontus_id']) && empty($input['prontus_id'])) {
    $ERROR_RESPONSE['msg'] = "Debe especificarse el parámetro '_prontus_id'";
    print json_encode($ERROR_RESPONSE);
    exit;
}

if (empty($input['prontus_id'])) {
    $CONFIG_YOUTUBE['PRONTUS_ID'] = $_GET['_prontus_id'];
} else {
    $CONFIG_YOUTUBE['PRONTUS_ID'] = $input['prontus_id'];
}

# Revisamos que exista la config de Prontus:
if (! file_exists($CONFIG_YOUTUBE['DOCUMENT_ROOT'].'/'.$CONFIG_YOUTUBE['PRONTUS_ID'].'/cpan/'.$CONFIG_YOUTUBE['PRONTUS_ID'].'-bd.cfg')) {
    $ERROR_RESPONSE['msg'] = "No pudo encontrarse la configuración de Prontus.";
    print json_encode($ERROR_RESPONSE);
    exit;
}

# Revisamos que exista la config de redes sociales:
if (! file_exists($CONFIG_YOUTUBE['DOCUMENT_ROOT'].'/'.$CONFIG_YOUTUBE['PRONTUS_ID'].'/cpan/'.$CONFIG_YOUTUBE['PRONTUS_ID'].'.cfg')) {
    $ERROR_RESPONSE['msg'] = "No pudo encontrarse el archivo de configuración de Posting a Redes Sociales.";
    print json_encode($ERROR_RESPONSE);
    exit;
}

# leemos el archivo de config.
$opciones_redes = parse_ini_file($CONFIG_YOUTUBE['DOCUMENT_ROOT'].'/'.$CONFIG_YOUTUBE['PRONTUS_ID'].'/cpan/'.$CONFIG_YOUTUBE['PRONTUS_ID'].'.cfg');
if ($opciones_redes === FALSE) {
    $ERROR_RESPONSE['msg'] = "No pudo leerse el archivo de configuración de Posting a Redes Sociales.";
    print json_encode($ERROR_RESPONSE);
    exit;
}

foreach ($opciones_redes as $key=>$value) {
    if (strpos($key, 'YOUTUBE_') === 0) {
        $CONFIG_YOUTUBE[$key] = $value;
    }
}

// Estado de privacidad del video. Pasar a Public para productivo.
$CONFIG_YOUTUBE['PRIVACY_STATUS'] = 'unlisted'; //Options are "public", "private" and "unlisted".

# limpiamos variable que ya no sirve.
unset($opciones_redes);
